.. image:: https://circleci.com/gh/dialoguemd/menhir.svg?style=svg&circle-token=b8e7721a127637996efff118d0b17aa7522cc96f
    :target: https://circleci.com/gh/dialoguemd/menhir

.. image:: https://codecov.io/gh/dialoguemd/menhir/branch/master/graph/badge.svg?token=Fl2ObQ8DC6
   :target: https://codecov.io/gh/dialoguemd/menhir

Menhir is a build tool for monolithic repositories.  Unlike existing
monolithic build tools, it does not aim at being prescriptive about
how (sub-)projects are built.  It prefers to use established single
project build tools at the project level.


Documentation
-------------

See `ReadTheDocs <https://dialogue-menhir.readthedocs-hosted.com/en/latest/>`_
for documentation.


Installation
------------

Install using `pip`.

    pip install menhir
